@@ -1,5 +1,5 @@
 #!python
-# Copyright (c) 2012 gocept gmbh & co. kg
+# Copyright (c) gocept gmbh & co. kg
 # See also LICENSE.txt
 
 """Nagios plugin to check number of logged in users."""
@@ -34,12 +34,14 @@ class Users(nagiosplugin.Resource):
         logging.info('querying users with "%s" command', self.who_cmd)
         users = []
         try:
-            for line in subprocess.check_output([self.who_cmd]).splitlines():
+            p = subprocess.Popen([self.who_cmd], stdout=subprocess.PIPE,
+                                 stdin=subprocess.PIPE)
+            for line in p.communicate()[0].splitlines():
                 logging.debug('who output: %s', line.strip())
                 users.append(line.split()[0].decode())
         except OSError:
             raise nagiosplugin.CheckError(
-                'cannot determine number of users ({} failed)'.format(
+                'cannot determine number of users ({0} failed)'.format(
                     self.who_cmd))
         return users
 
