@@ -1,9 +1,13 @@
-# Copyright (c) 2012 gocept gmbh & co. kg
+# Copyright (c) gocept gmbh & co. kg
 # See also LICENSE.txt
 
 from nagiosplugin.metric import Metric
 import nagiosplugin
-import unittest
+
+try:
+    import unittest2 as unittest
+except ImportError:  # pragma: no cover
+    import unittest
 
 
 class MetricTest(unittest.TestCase):
